@@ -13,8 +13,8 @@ def getgpt(OpenAI_Token, Request):
 			stop=None,
 			temperature=0.5,
 		).get("choices")[0].text
-		return print(resp)
+		return resp
 	except Exception as e:
-		return print(f'Error while connect to openai.\nError: {e}')
+		return f'Error while connect to openai.\nError: {e}'
 
 
